ERROR: The request could not be satisfied

# 421 ERROR

## The request could not be satisfied.

The distribution does not match the certificate for which the HTTPS connection was established with. We can't connect to the server for this app or website at this time. There might be too much traffic or a configuration error. Try again later, or contact the app or website owner.
If you provide content to customers through CloudFront, you can find steps to troubleshoot and help prevent this error by reviewing the CloudFront documentation.

    Generated by cloudfront (CloudFront)
    Request ID: eIGjchnBWsXRGF-fhAOgJ_AKXAgNfqvzXhUKSvMMl6Iuk1AeiR9Kaw==